average_toxicity: Average Toxicity Number

average_toxicityR Documentation

Average Toxicity Number

Description

Calculate the Average Toxicity Number.

Usage

average_toxicity(dose, dose_set, true_prob, theta)

Arguments

dose

a numerical matrix of assigned doses for each step of the trial (column) and for each trial (row).

dose_set

a numerical vector of allowable doses in the trial.

true_prob

a numerical vector of the true probabilities associated with 'dose_set'.

theta

a numerical value defining the proportion of expected patients to experience a medically unacceptable, dose-limiting toxicity (DLT) if administered the MTD.

Value

Average Toxicity Number.

References

Cheung, Y. K. (2011). Dose finding by the continual reassessment method. CRC Press.


ewoc documentation built on Sept. 1, 2026, 1:08 a.m.