dlt_curve_d1extended: Plot the DLT curve based on the EWOC extended model

View source: R/dlt_curve.R

dlt_curve_d1extendedR Documentation

Plot the DLT curve based on the EWOC extended model

Description

Plot the DLT curve based on the EWOC extended model

Usage

dlt_curve_d1extended(rho, theta, min_dose, max_dose, dose_set = NULL)

Arguments

rho

a numerical vector indicating the true value of the parameters rho_0 and rho_1.

theta

a numerical value defining the proportion of expected patients to experience a medically unacceptable, dose-limiting toxicity (DLT) if administered the MTD.

min_dose

a numerical value defining the lower bound of the support of the MTD.

max_dose

a numerical value defining the upper bound of the support of the MTD.

dose_set

a numerical vector of doses that probability of DLT will be calculated.


ewoc documentation built on Sept. 1, 2026, 1:08 a.m.