| standard_dose | R Documentation |
Standardizing a dose between 0 and 1.
standard_dose(dose, min_dose, max_dose)
dose |
a numerical value defining the dose to be standardized. |
min_dose |
a numerical value defining the lower bound of the support of the MTD. |
max_dose |
a numerical value defining the upper bound of the support of the MTD. |
standardized dose a numerical value between 0 and 1.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.