stop_rule_d1extended: Generating a stopping rule function for EWOC extended model

View source: R/stop_rule.R

stop_rule_d1extendedR Documentation

Generating a stopping rule function for EWOC extended model

Description

Generating a stopping rule function for EWOC extended model

Usage

stop_rule_d1extended(step)

Arguments

step

an object from the class ewoc_d1extended.

Details

The function is evaluated at each step of the trial. It can defined based on any information contained in the object step that is the output from one of the functions ewoc_d1extended.

Value

a logical character indicating if the trial should be stopped or not.

Examples



## Not run: 
DLT <- 0
dose <- 20
step_zero <- ewoc_d1extended(DLT ~ dose, type = 'discrete',
                           theta = 0.33, alpha = 0.25,
                           min_dose = 0, max_dose = 100,
                           dose_set = seq(0, 100, 20),
                           rho_prior = matrix(1, ncol = 2, nrow = 2),
                           rounding = "nearest")
stop_rule_d1extended(step_zero)
response_sim <- response_d1extended(rho = c(0.05, 0.95),
                                   min_dose = 10, max_dose = 50)
sim <- ewoc_simulation(step_zero = step_zero,
                       n_sim = 2, sample_size = 30,
                       alpha_strategy = "conditional",
                       response_sim = response_sim,
                       stop_rule_sim = stop_rule_d1extended,
                       ncores = 1)

## End(Not run)

ewoc documentation built on Sept. 1, 2026, 1:08 a.m.